==> distribution-5.50.0.zip: drr/projection/iso20022/jfsa/rewrite/margin/functions/Create_CounterpartySpecificData.java <==
package drr.projection.iso20022.jfsa.rewrite.margin.functions;

import com.google.inject.ImplementedBy;
import com.rosetta.model.lib.expression.CardinalityOperator;
import com.rosetta.model.lib.functions.ModelObjectValidator;
import com.rosetta.model.lib.functions.RosettaFunction;
import com.rosetta.model.lib.mapper.MapperS;
import drr.regulation.jfsa.rewrite.margin.CollateralReport;
import drr.regulation.jfsa.rewrite.margin.PartiesToTheDerivative;
import iso20022.auth108.jfsa.Counterparty45__1;
import iso20022.auth108.jfsa.Counterparty46__1;
import iso20022.auth108.jfsa.GenericIdentification175__1;
import iso20022.auth108.jfsa.LegalPersonIdentification1__1;
import iso20022.auth108.jfsa.LegalPersonIdentification1__2;
import iso20022.auth108.jfsa.NaturalPersonIdentification2__1;
import iso20022.auth108.jfsa.NaturalPersonIdentification3__1;
import iso20022.auth108.jfsa.OrganisationIdentification15Choice__1;
import iso20022.auth108.jfsa.OrganisationIdentification15Choice__2;
import iso20022.auth108.jfsa.PartyIdentification248Choice__1;
import iso20022.auth108.jfsa.PartyIdentification248Choice__2;
import iso20022.auth108.jfsa.TradeCounterpartyReport20__1;
import java.util.Optional;
import javax.inject.Inject;

import static com.rosetta.model.lib.expression.ExpressionOperators.*;

@ImplementedBy(Create_CounterpartySpecificData.Create_CounterpartySpecificDataDefault.class)
public abstract class Create_CounterpartySpecificData implements RosettaFunction {
	
	@Inject protected ModelObjectValidator objectValidator;

	/**
	* @param partiesToTheDerivative 
	* @param collateralReport 
	* @return ctrPtySpcfcData 
	*/
	public TradeCounterpartyReport20__1 evaluate(PartiesToTheDerivative partiesToTheDerivative, CollateralReport collateralReport) {
		TradeCounterpartyReport20__1.TradeCounterpartyReport20__1Builder ctrPtySpcfcDataBuilder = doEvaluate(partiesToTheDerivative, collateralReport);
		
		final TradeCounterpartyReport20__1 ctrPtySpcfcData;
		if (ctrPtySpcfcDataBuilder == null) {
			ctrPtySpcfcData = null;
		} else {
			ctrPtySpcfcData = ctrPtySpcfcDataBuilder.build();
			objectValidator.validate(TradeCounterpartyReport20__1.class, ctrPtySpcfcData);
		}
		
		return ctrPtySpcfcData;
	}

	protected abstract TradeCounterpartyReport20__1.TradeCounterpartyReport20__1Builder doEvaluate(PartiesToTheDerivative partiesToTheDerivative, CollateralReport collateralReport);

	public static class Create_CounterpartySpecificDataDefault extends Create_CounterpartySpecificData {
		@Override
		protected TradeCounterpartyReport20__1.TradeCounterpartyReport20__1Builder doEvaluate(PartiesToTheDerivative partiesToTheDerivative, CollateralReport collateralReport) {
			TradeCounterpartyReport20__1.TradeCounterpartyReport20__1Builder ctrPtySpcfcData = TradeCounterpartyReport20__1.builder();
			return assignOutput(ctrPtySpcfcData, partiesToTheDerivative, collateralReport);
		}
		
		protected TradeCounterpartyReport20__1.TradeCounterpartyReport20__1Builder assignOutput(TradeCounterpartyReport20__1.TradeCounterpartyReport20__1Builder ctrPtySpcfcData, PartiesToTheDerivative partiesToTheDerivative, CollateralReport collateralReport) {
			LegalPersonIdentification1__2 ifThenElseResult0 = null;
			if (areEqual(MapperS.of(partiesToTheDerivative).<Boolean>map("getCounterparty2IdentifierType", _partiesToTheDerivative -> _partiesToTheDerivative.getCounterparty2IdentifierType()), MapperS.of(true), CardinalityOperator.All).getOrDefault(false)) {
				ifThenElseResult0 = LegalPersonIdentification1__2.builder()
					.setId(OrganisationIdentification15Choice__2.builder()
						.setLei(MapperS.of(partiesToTheDerivative).<String>map("getCounterparty2", _partiesToTheDerivative -> _partiesToTheDerivative.getCounterparty2()).get())
						.build())
					.build();
			}
			NaturalPersonIdentification3__1 ifThenElseResult1 = null;
			if (areEqual(MapperS.of(partiesToTheDerivative).<Boolean>map("getCounterparty2IdentifierType", _partiesToTheDerivative -> _partiesToTheDerivative.getCounterparty2IdentifierType()), MapperS.of(false), CardinalityOperator.All).getOrDefault(false)) {
				ifThenElseResult1 = NaturalPersonIdentification3__1.builder()
					.setId(NaturalPersonIdentification2__1.builder()
						.setId(GenericIdentification175__1.builder()
							.setId(MapperS.of(partiesToTheDerivative).<String>map("getCounterparty2", _partiesToTheDerivative -> _partiesToTheDerivative.getCounterparty2()).get())
							.build())
						.build())
					.build();
			}
			ctrPtySpcfcData = toBuilder(TradeCounterpartyReport20__1.builder()
				.setRptgCtrPty(Counterparty45__1.builder()
					.setId(PartyIdentification248Choice__1.builder()
						.setLgl(LegalPersonIdentification1__1.builder()
							.setId(OrganisationIdentification15Choice__1.builder()
								.setLei(MapperS.of(partiesToTheDerivative).<String>map("getCounterparty1", _partiesToTheDerivative -> _partiesToTheDerivative.getCounterparty1()).get())
								.build())
							.build())
						.build())
					.build())
				.setSubmitgAgt(OrganisationIdentification15Choice__1.builder()
					.setLei(MapperS.of(partiesToTheDerivative).<String>map("getSubmitterIdentifier", _partiesToTheDerivative -> _partiesToTheDerivative.getSubmitterIdentifier()).get())
					.build())
				.setOthrCtrPty(Counterparty46__1.builder()
					.setIdTp(PartyIdentification248Choice__2.builder()
						.setLgl(ifThenElseResult0)
						.setNtrl(ifThenElseResult1)
						.build())
					.build())
				.setNttyRspnsblForRpt(OrganisationIdentification15Choice__1.builder()
					.setLei(MapperS.of(partiesToTheDerivative).<String>map("getEntityResponsibleForReporting", _partiesToTheDerivative -> _partiesToTheDerivative.getEntityResponsibleForReporting()).get())
					.build())
				.build());
			
			return Optional.ofNullable(ctrPtySpcfcData)
				.map(o -> o.prune())
				.orElse(null);
		}
	}
}

==> distribution-5.55.0.zip: drr/projection/iso20022/jfsa/rewrite/margin/functions/Create_CounterpartySpecificData.java <==
package drr.projection.iso20022.jfsa.rewrite.margin.functions;

import com.google.inject.ImplementedBy;
import com.rosetta.model.lib.expression.CardinalityOperator;
import com.rosetta.model.lib.functions.ModelObjectValidator;
import com.rosetta.model.lib.functions.RosettaFunction;
import com.rosetta.model.lib.mapper.MapperS;
import drr.regulation.jfsa.rewrite.margin.CollateralReport;
import drr.regulation.jfsa.rewrite.margin.PartiesToTheDerivative;
import iso20022.auth108.jfsa.Counterparty45__1;
import iso20022.auth108.jfsa.Counterparty46__1;
import iso20022.auth108.jfsa.GenericIdentification175__1;
import iso20022.auth108.jfsa.LegalPersonIdentification1__1;
import iso20022.auth108.jfsa.LegalPersonIdentification1__2;
import iso20022.auth108.jfsa.NaturalPersonIdentification2__1;
import iso20022.auth108.jfsa.NaturalPersonIdentification3__1;
import iso20022.auth108.jfsa.OrganisationIdentification15Choice__1;
import iso20022.auth108.jfsa.OrganisationIdentification15Choice__2;
import iso20022.auth108.jfsa.PartyIdentification248Choice__1;
import iso20022.auth108.jfsa.PartyIdentification248Choice__2;
import iso20022.auth108.jfsa.TradeCounterpartyReport20__1;
import java.util.Optional;
import javax.inject.Inject;

import static com.rosetta.model.lib.expression.ExpressionOperatorsNullSafe.*;

@ImplementedBy(Create_CounterpartySpecificData.Create_CounterpartySpecificDataDefault.class)
public abstract class Create_CounterpartySpecificData implements RosettaFunction {
	
	@Inject protected ModelObjectValidator objectValidator;

	/**
	* @param partiesToTheDerivative 
	* @param collateralReport 
	* @return ctrPtySpcfcData 
	*/
	public TradeCounterpartyReport20__1 evaluate(PartiesToTheDerivative partiesToTheDerivative, CollateralReport collateralReport) {
		TradeCounterpartyReport20__1.TradeCounterpartyReport20__1Builder ctrPtySpcfcDataBuilder = doEvaluate(partiesToTheDerivative, collateralReport);
		
		final TradeCounterpartyReport20__1 ctrPtySpcfcData;
		if (ctrPtySpcfcDataBuilder == null) {
			ctrPtySpcfcData = null;
		} else {
			ctrPtySpcfcData = ctrPtySpcfcDataBuilder.build();
			objectValidator.validate(TradeCounterpartyReport20__1.class, ctrPtySpcfcData);
		}
		
		return ctrPtySpcfcData;
	}

	protected abstract TradeCounterpartyReport20__1.TradeCounterpartyReport20__1Builder doEvaluate(PartiesToTheDerivative partiesToTheDerivative, CollateralReport collateralReport);

	public static class Create_CounterpartySpecificDataDefault extends Create_CounterpartySpecificData {
		@Override
		protected TradeCounterpartyReport20__1.TradeCounterpartyReport20__1Builder doEvaluate(PartiesToTheDerivative partiesToTheDerivative, CollateralReport collateralReport) {
			TradeCounterpartyReport20__1.TradeCounterpartyReport20__1Builder ctrPtySpcfcData = TradeCounterpartyReport20__1.builder();
			return assignOutput(ctrPtySpcfcData, partiesToTheDerivative, collateralReport);
		}
		
		protected TradeCounterpartyReport20__1.TradeCounterpartyReport20__1Builder assignOutput(TradeCounterpartyReport20__1.TradeCounterpartyReport20__1Builder ctrPtySpcfcData, PartiesToTheDerivative partiesToTheDerivative, CollateralReport collateralReport) {
			LegalPersonIdentification1__2 ifThenElseResult0 = null;
			if (areEqual(MapperS.of(partiesToTheDerivative).<Boolean>map("getCounterparty2IdentifierType", _partiesToTheDerivative -> _partiesToTheDerivative.getCounterparty2IdentifierType()), MapperS.of(true), CardinalityOperator.All).getOrDefault(false)) {
				ifThenElseResult0 = LegalPersonIdentification1__2.builder()
					.setId(OrganisationIdentification15Choice__2.builder()
						.setLei(MapperS.of(partiesToTheDerivative).<String>map("getCounterparty2", _partiesToTheDerivative -> _partiesToTheDerivative.getCounterparty2()).get())
						.build())
					.build();
			}
			NaturalPersonIdentification3__1 ifThenElseResult1 = null;
			if (areEqual(MapperS.of(partiesToTheDerivative).<Boolean>map("getCounterparty2IdentifierType", _partiesToTheDerivative -> _partiesToTheDerivative.getCounterparty2IdentifierType()), MapperS.of(false), CardinalityOperator.All).getOrDefault(false)) {
				ifThenElseResult1 = NaturalPersonIdentification3__1.builder()
					.setId(NaturalPersonIdentification2__1.builder()
						.setId(GenericIdentification175__1.builder()
							.setId(MapperS.of(partiesToTheDerivative).<String>map("getCounterparty2", _partiesToTheDerivative -> _partiesToTheDerivative.getCounterparty2()).get())
							.build())
						.build())
					.build();
			}
			ctrPtySpcfcData = toBuilder(TradeCounterpartyReport20__1.builder()
				.setRptgCtrPty(Counterparty45__1.builder()
					.setId(PartyIdentification248Choice__1.builder()
						.setLgl(LegalPersonIdentification1__1.builder()
							.setId(OrganisationIdentification15Choice__1.builder()
								.setLei(MapperS.of(partiesToTheDerivative).<String>map("getCounterparty1", _partiesToTheDerivative -> _partiesToTheDerivative.getCounterparty1()).get())
								.build())
							.build())
						.build())
					.build())
				.setSubmitgAgt(OrganisationIdentification15Choice__1.builder()
					.setLei(MapperS.of(partiesToTheDerivative).<String>map("getSubmitterIdentifier", _partiesToTheDerivative -> _partiesToTheDerivative.getSubmitterIdentifier()).get())
					.build())
				.setOthrCtrPty(Counterparty46__1.builder()
					.setIdTp(PartyIdentification248Choice__2.builder()
						.setLgl(ifThenElseResult0)
						.setNtrl(ifThenElseResult1)
						.build())
					.build())
				.setNttyRspnsblForRpt(OrganisationIdentification15Choice__1.builder()
					.setLei(MapperS.of(partiesToTheDerivative).<String>map("getEntityResponsibleForReporting", _partiesToTheDerivative -> _partiesToTheDerivative.getEntityResponsibleForReporting()).get())
					.build())
				.build());
			
			return Optional.ofNullable(ctrPtySpcfcData)
				.map(o -> o.prune())
				.orElse(null);
		}
	}
}
